encode_auto_micro

Function encode_auto_micro 

pub fn encode_auto_micro(data: &[u8], ec_level: EcLevel) -> QrResult<Bits>
Automatically determines the minimum Micro QR version to store the data, and encode the result.

This method only considers Micro QR code versions (1–4).

Errors

Returns Err(QrError::DataTooLong) if the data is too long to fit even the highest Micro QR version.

Returns Err(QrError::InvalidVersion) if the ec_level is not supported by any Micro QR version (e.g. EcLevel::H).