pub enum PluginError {
RendererNotFound(String),
EncoderNotFound(String),
InvalidConfig(String),
InvalidModuleGrid,
RenderFailed(String),
EncodeFailed(String),
PostProcessFailed(String),
}Expand description
Error type used by object-safe plugin entry points.
Variants
RendererNotFound(String)
A named renderer was not present in the registry.
EncoderNotFound(String)
A named encoder was not present in the registry.
InvalidConfig(String)
The plugin configuration was invalid.
InvalidModuleGrid
A module grid shape was invalid.
RenderFailed(String)
A renderer failed.
EncodeFailed(String)
An encoder failed.
PostProcessFailed(String)
A postprocessor failed.